# coding: utf-8

from ..utils.language import Language


class ApiCode:

    invalidToken = "invalidToken"
    invalidSender = "invalidSender"
    invalidReceiver = "invalidReceiver"
    invalidExternalId = "invalidExternalId"
    invalidAmount = "invalidAmount"
    invalidSenderFee = "invalidSenderFee"
    invalidReceiverFee = "invalidReceiverFee"
    invalidBalance = "invalidBalance"
    invalidDigitalSignature = "invalidDigitalSignature"
    invalidPublicKey = "invalidPublicKey"
    invalidDate = "invalidDate"
    invalidAccount = "invalidAccount"
    invalidPermission = "invalidPermission"


class ApiMessageKey:

    publicKeySent = "publicKeySent"
    publicKeySaved = "publicKeySaved"
    invalidOrExpiredToken = "invalidOrExpiredToken"
    usedParameter = "usedParameter"
    objectNotFound = "objectNotFound"
    objectNotAllowed = "objectNotAllowed"
    missingParameter = "missingParameter"
    invalidParameter = "invalidParameter"
    positiveInteger = "positiveInteger"
    noFunds = "noFunds"
    invalidDateOrder = "invalidDateOrder"
    missAdminOrFinantialRole = "missAdminOrFinantialRole"


class ApiMessage:

    @classmethod
    def get(cls, key, language, **data):
        content = {
            Language.english: {
                ApiMessageKey.publicKeySent:            "Token successfuly sent to email {}".format(data.get("email")),
                ApiMessageKey.publicKeySaved:           "Public key saved with success",
                ApiMessageKey.invalidOrExpiredToken:    "Invalid or expired token",
                ApiMessageKey.usedParameter:            "This %s has already been used, you should use another one" % data.get("parameter"),
                ApiMessageKey.objectNotFound:           "%s not found" % data.get("object"),
                ApiMessageKey.objectNotAllowed:         "You are not allowed to access this object",
                ApiMessageKey.missingParameter:         "Missing \"%s\" %s" % (data.get("parameter"), data.get("type", "parameter")),
                ApiMessageKey.invalidParameter:         "\"%s\" %s is not valid" % (data.get("parameter"), data.get("type", "value")),
                ApiMessageKey.positiveInteger:          "\"%s\" must be a positive integer greater than zero" % data.get("parameter"),
                ApiMessageKey.noFunds:                  "You have not enough funds in your account",
                ApiMessageKey.invalidDateOrder:         "\"After\" must always be less than \"Before\"",
                ApiMessageKey.missAdminOrFinantialRole: "Verify if you have financial or admin in Workspace Permission to access this information"
            },
            Language.portuguese: {
                ApiMessageKey.publicKeySent:            "Código enviado com sucesso para o email {}".format(data.get("email")),
                ApiMessageKey.publicKeySaved:           "Chave pública salva com sucesso",
                ApiMessageKey.invalidOrExpiredToken:    "Código inválido ou expirado",
                ApiMessageKey.usedParameter:            "Esse(a) %s já foi utilizado, você deve utilizar outro" % data.get("parameter"),
                ApiMessageKey.objectNotFound:           "%s não encontrado" % data.get("object"),
                ApiMessageKey.objectNotAllowed:         "Você não pode acessar esse objeto",
                ApiMessageKey.missingParameter:         "O %s \"%s\" está faltando" % (data.get("type", "parametro"), data.get("parameter")),
                ApiMessageKey.invalidParameter:         "O %s \"%s\" não é válido" % (data.get("type", "valor"), data.get("parameter")),
                ApiMessageKey.positiveInteger:          "\"%s\" deve ser um inteiro positivo maior do que zero" % data.get("parameter"),
                ApiMessageKey.noFunds:                  "Você não possui saldo suficiente em sua conta",
                ApiMessageKey.invalidDateOrder:         "\"After\" deve ser sempre uma data inferior a \"Before\"",
                ApiMessageKey.missAdminOrFinantialRole: "Em Permissões de Workspace, verifique se você possui permissão de financeiro ou administrador para acessar essa informação"
            }
        }

        if key not in content[language]:
            return "Unknown api message for key: " + key
        return content[language][key]